==> qtjambi-script-debuginfo-macos-5.15.18.jar: sources/QtJambiScript/QScriptSyntaxCheckResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScript/qscriptengine.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScriptSyntaxCheckResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScriptSyntaxCheckResult")
    QScriptSyntaxCheckResult *_ptr = reinterpret_cast<QScriptSyntaxCheckResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)
void __qt_construct_QScriptSyntaxCheckResult_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)")
    jobject other0 = __java_arguments[0].l;
    const QScriptSyntaxCheckResult& __qt_other0 = qtjambi_cast<const QScriptSyntaxCheckResult& >(__jni_env, other0);
    QScriptSyntaxCheckResult *__qt_this = new(__qtjambi_ptr) QScriptSyntaxCheckResult(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QScriptSyntaxCheckResult
void __qt_destruct_QScriptSyntaxCheckResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScriptSyntaxCheckResult")
    reinterpret_cast<QScriptSyntaxCheckResult*>(ptr)->~QScriptSyntaxCheckResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScriptSyntaxCheckResult::QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_initialize_1native__Lio_qt_script_QScriptSyntaxCheckResult_2Lio_qt_script_QScriptSyntaxCheckResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptSyntaxCheckResult::QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptSyntaxCheckResult_0, sizeof(QScriptSyntaxCheckResult), typeid(QScriptSyntaxCheckResult), false, &deleter_QScriptSyntaxCheckResult, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptSyntaxCheckResult::errorColumnNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_errorColumnNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::errorColumnNumber()const", __qt_this)
        __java_return_value = __qt_this->errorColumnNumber();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptSyntaxCheckResult::errorLineNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_errorLineNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::errorLineNumber()const", __qt_this)
        __java_return_value = __qt_this->errorLineNumber();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptSyntaxCheckResult::errorMessage()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_errorMessage_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::errorMessage()const", __qt_this)
        QString __qt_return_value = __qt_this->errorMessage();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptSyntaxCheckResult::operator=(QScriptSyntaxCheckResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_assign_1native_1cref_1QScriptSyntaxCheckResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::operator=(QScriptSyntaxCheckResult)", __qt_this)
        const QScriptSyntaxCheckResult& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QScriptSyntaxCheckResult>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptSyntaxCheckResult::state()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_state_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::state()const", __qt_this)
        QScriptSyntaxCheckResult::State __qt_return_value = __qt_this->state();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void* custom_constructor_QScriptSyntaxCheckResult(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QScriptSyntaxCheckResult* copy = static_cast<const QScriptSyntaxCheckResult*>(__in_var);
    Q_UNUSED(copy)
    if(copy)
        return new(placement) QScriptSyntaxCheckResult(*copy);
    else
        return nullptr;
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScriptSyntaxCheckResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QScriptSyntaxCheckResult>("QScriptSyntaxCheckResult", "io/qt/script/QScriptSyntaxCheckResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScriptSyntaxCheckResult, {
        ConstructorInfo(&__qt_construct_QScriptSyntaxCheckResult_0, "Lio/qt/script/QScriptSyntaxCheckResult;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScriptSyntaxCheckResult);
    registerMetaType<QScriptSyntaxCheckResult>("QScriptSyntaxCheckResult", &custom_constructor_QScriptSyntaxCheckResult);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QScriptSyntaxCheckResult::State>("QScriptSyntaxCheckResult::State", "io/qt/script/QScriptSyntaxCheckResult$State");
// END: enums and flags
}

==> qtjambi-script-debuginfo-macos-5.15.20.jar: sources/QtJambiScript/QScriptSyntaxCheckResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScript/qscriptengine.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScriptSyntaxCheckResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScriptSyntaxCheckResult")
    QScriptSyntaxCheckResult *_ptr = reinterpret_cast<QScriptSyntaxCheckResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)
void __qt_construct_QScriptSyntaxCheckResult_cref_QScriptSyntaxCheckResult(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)")
    jobject other0 = __java_arguments[0].l;
    const QScriptSyntaxCheckResult& __qt_other0 = qtjambi_cast<const QScriptSyntaxCheckResult& >(__jni_env, other0);
    QScriptSyntaxCheckResult *__qt_this = new(__qtjambi_ptr) QScriptSyntaxCheckResult(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScriptSyntaxCheckResult::QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_initialize_1native__Lio_qt_script_QScriptSyntaxCheckResult_2Lio_qt_script_QScriptSyntaxCheckResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptSyntaxCheckResult::QScriptSyntaxCheckResult(QScriptSyntaxCheckResult)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptSyntaxCheckResult_cref_QScriptSyntaxCheckResult, sizeof(QScriptSyntaxCheckResult), typeid(QScriptSyntaxCheckResult), false, &deleter_QScriptSyntaxCheckResult, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScriptSyntaxCheckResult
void __qt_destruct_QScriptSyntaxCheckResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScriptSyntaxCheckResult")
    reinterpret_cast<QScriptSyntaxCheckResult*>(ptr)->~QScriptSyntaxCheckResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScriptSyntaxCheckResult::errorColumnNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_errorColumnNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::errorColumnNumber()const", __qt_this)
        __java_return_value = __qt_this->errorColumnNumber();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptSyntaxCheckResult::errorLineNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_errorLineNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::errorLineNumber()const", __qt_this)
        __java_return_value = __qt_this->errorLineNumber();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptSyntaxCheckResult::errorMessage()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_errorMessage_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::errorMessage()const", __qt_this)
        QString __qt_return_value = __qt_this->errorMessage();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptSyntaxCheckResult::operator=(QScriptSyntaxCheckResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_assign_1native_1cref_1QScriptSyntaxCheckResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::operator=(QScriptSyntaxCheckResult)", __qt_this)
        const QScriptSyntaxCheckResult& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QScriptSyntaxCheckResult>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptSyntaxCheckResult::state()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_state_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptSyntaxCheckResult::state()const", __qt_this)
        QScriptSyntaxCheckResult::State __qt_return_value = __qt_this->state();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void* custom_constructor_QScriptSyntaxCheckResult(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QScriptSyntaxCheckResult* copy = static_cast<const QScriptSyntaxCheckResult*>(__in_var);
    Q_UNUSED(copy)
    if(copy)
        return new(placement) QScriptSyntaxCheckResult(*copy);
    else
        return nullptr;
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptSyntaxCheckResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScriptSyntaxCheckResult *__qt_this = QtJambiAPI::objectFromNativeId<QScriptSyntaxCheckResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScriptSyntaxCheckResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QScriptSyntaxCheckResult>("QScriptSyntaxCheckResult", "io/qt/script/QScriptSyntaxCheckResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScriptSyntaxCheckResult, {
        ConstructorInfo(&__qt_construct_QScriptSyntaxCheckResult_cref_QScriptSyntaxCheckResult, "Lio/qt/script/QScriptSyntaxCheckResult;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScriptSyntaxCheckResult);
    registerMetaType<QScriptSyntaxCheckResult>("QScriptSyntaxCheckResult", &custom_constructor_QScriptSyntaxCheckResult);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QScriptSyntaxCheckResult::State>("QScriptSyntaxCheckResult::State", "io/qt/script/QScriptSyntaxCheckResult$State");
// END: enums and flags
}
